@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 
-use Sort::Flat qw/sort_f reverse_f/;
+use Sort::Flat qw(sort_f reverse_f);
 
 local $, = "\n";
 
